summaryrefslogtreecommitdiffstats
path: root/ash/shell_window_ids.h
diff options
context:
space:
mode:
authorvarunjain@chromium.org <varunjain@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-02 20:00:43 +0000
committervarunjain@chromium.org <varunjain@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-02 20:00:43 +0000
commit9dea0a214a4be39d628b756b359eb8e19f160d12 (patch)
treed641800523e7bcf006fc256ffdefa194d419aefc /ash/shell_window_ids.h
parent3de01d600a6ac2a3eb1cf2504ed52ee3bd10ec2d (diff)
downloadchromium_src-9dea0a214a4be39d628b756b359eb8e19f160d12.zip
chromium_src-9dea0a214a4be39d628b756b359eb8e19f160d12.tar.gz
chromium_src-9dea0a214a4be39d628b756b359eb8e19f160d12.tar.bz2
Aura: Create a new containerr for drag/drop images and tooltips.
BUG=111148 TEST=manual Review URL: https://chromiumcodereview.appspot.com/9314040 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@120230 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell_window_ids.h')
-rw-r--r--ash/shell_window_ids.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/ash/shell_window_ids.h b/ash/shell_window_ids.h
index fcca022..981698f 100644
--- a/ash/shell_window_ids.h
+++ b/ash/shell_window_ids.h
@@ -43,12 +43,15 @@ const int kShellWindowId_LockSystemModalContainer = 8;
// The container for the status area.
const int kShellWindowId_StatusContainer = 9;
-// The container for menus and tooltips.
-const int kShellWindowId_MenuAndTooltipContainer = 10;
+// The container for menus.
+const int kShellWindowId_MenuContainer = 10;
+
+// The container for drag/drop images and tooltips.
+const int kShellWindowId_DragImageAndTooltipContainer = 11;
// The container for bubbles briefly overlaid onscreen to show settings changes
// (volume, brightness, etc.).
-const int kShellWindowId_SettingBubbleContainer = 11;
+const int kShellWindowId_SettingBubbleContainer = 12;
} // namespace internal